@@ -660,7 +660,13 @@ after a short delay.  N is the count of checks done so far."
               (el-job--dbg 2 "Dead process buffer (this may be normal)")
             (set-buffer buf)
             (if (eq (char-before) ?\n)
-                (el-job--handle-output)
+                (if (string-blank-p (buffer-string))
+                    (progn
+                      ;; https://github.com/meedstrom/org-mem/issues/25
+                      (el-job--dbg 2 "Process buffer empty, assuming not yet filled: %S"
+                                   buf)
+                      (push buf busy-bufs))
+                  (el-job--handle-output))
               (push buf busy-bufs))))
         (cl-assert el-job-here)
         (when (member (el-job-timer el-job-here) timer-list)
